@@ -7,4 +7,4 @@ def bool_to_number(value):
     :param value: Any boolean value
     :return: "1" when True. Otherwise, "0"
     """
-    return "1" if value else "0"
+    return 1 if value else 0
